@@ -2,15 +2,15 @@ use Object::Pad ':experimental(init_expr)';
 
 package OpenTelemetry::SDK::InstrumentationScope;
 
-our $VERSION = '0.026';
+our $VERSION = '0.027';
 
 class OpenTelemetry::SDK::InstrumentationScope :does(OpenTelemetry::Attributes) {
-    use Log::Any;
+    use OpenTelemetry::Common;
 
     field $name    :param :reader;
     field $version :param :reader //= '';
 
-    my $logger = Log::Any->get_logger( category => 'OpenTelemetry' );
+    my $logger = OpenTelemetry::Common::internal_logger;
 
     ADJUST {
         $name ||= do {
