@@ -3,12 +3,14 @@ use Object::Pad;
 
 package OpenTelemetry::SDK::Trace::Tracer;
 
-our $VERSION = '0.026';
+our $VERSION = '0.027';
 
 class OpenTelemetry::SDK::Trace::Tracer :isa(OpenTelemetry::Trace::Tracer) {
     use OpenTelemetry::Constants 'SPAN_KIND_INTERNAL';
     use OpenTelemetry::Context;
     use OpenTelemetry::Trace;
+    use OpenTelemetry::Common ();
+    use Ref::Util 'is_hashref';
 
     field $span_creator :param;
 
@@ -16,6 +18,12 @@ class OpenTelemetry::SDK::Trace::Tracer :isa(OpenTelemetry::Trace::Tracer) {
         $args{name} //= 'empty';
         $args{kind} //= SPAN_KIND_INTERNAL;
 
+        unless (is_hashref( $args{attributes} // {} )) {
+            OpenTelemetry::Common::internal_logger
+                ->warn('The \'attributes\' parameter to create_span must be a hash reference, it was instead a ' . ( ref($args{attribute}) || 'plain scalar' ) );
+            delete $args{attributes};
+        }
+
         $args{context} = OpenTelemetry::Context->current
             unless exists $args{context};
 
